@@ -11,10 +11,11 @@ top of the :class:`abstract base class <~ae.gui_app.MainAppBase>`
 (implemented in the :mod:`ae.gui_app` portion of the
 ae namespace):
 
-* :mod:`Kivy <ae.kivy_app>` - see also :ref:`kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`
-* :mod:`Enaml <ae.enaml_app>` - see also :ref:`enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`
-* :mod:`Beeware <ae.beeware_app>`
-* :mod:`QPython <ae.qpython_app>`
+* :mod:`Kivy <ae.kivy_app>` based on the `kivy framework <https://kivy.org>`__:
+  `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`__
+* :mod:`Enaml <ae.enaml_app>` based on `the enaml framework <https://enaml.readthedocs.io/en/latest/>`__:
+  `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__
+* :mod:`Beeware Toga <ae.toga_app>` based on `the beeware/toga framework <https://beeware.org>`__:
 * :mod:`pyglet <ae.pyglet_app>`
 * :mod:`pygobject <ae.pygobject_app>`
 * :mod:`Dabo <ae.dabo_app>`
@@ -107,19 +108,19 @@ gui framework implementation variants
 kivy
 ----
 
-The :ref:`kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>` is based
-on the :ref:`kivy framework <https://kivy.org>`,
-a :ref:`pypi package <https://pypi.org/project/Kivy/>`
-documented :ref:`here <https://kivy.org/doc/stable/>`.
+The `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`__ is based
+on the `kivy framework <https://kivy.org>`__,
+a `pypi package <https://pypi.org/project/Kivy/>`__
+documented `here <https://kivy.org/doc/stable/>`__.
 
 
 enaml
 -----
 
-The :ref:`enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>` is
-based on the :ref:`enaml framework <https://pypi.org/project/enaml/>`,
-a :ref:`pypi package <https://pypi.org/project/enaml/>`
-documented :ref:`here at ReadTheDocs <https://enaml.readthedocs.io/en/latest/>`.
+The `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__ is
+based on the `enaml framework <https://pypi.org/project/enaml/>`__,
+a `pypi package <https://pypi.org/project/enaml/>`__
+documented `here at ReadTheDocs <https://enaml.readthedocs.io/en/latest/>`__.
 
 
 automatic update of widget attributes
@@ -233,7 +234,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action       # type: ignore
 
 
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 
 
 FLOW_PATH_ROOT_ID = '<<<root>>>'     #: needed for flow path jumper and for drop onto leave item button
@@ -329,18 +330,22 @@ class LiszDataMixin(ABC):
         self.play_sound('deleted')
 
     def edit_validate(self, old_idx: int,
-                      new_id: Optional[str] = None, want_node: Optional[bool] = None, toggle_sel: bool = False) -> str:
+                      new_id: Optional[str] = None, want_node: Optional[bool] = None,
+                      toggle_sel: bool = False, toggle_unselected: bool = False) -> str:
         """ validate the user changes after adding a new item or editing an existing item.
 
-        :param old_idx:         index in the current node of the edited item or -1 if a new item got edited.
-        :param new_id:          new/edited id string.
-        :param want_node:       True if the new/edited item will have a sub-node, False if not.
-        :param toggle_sel:      True if the selection state of the item has to be toggled.
-        :return:                empty string on successful validation, else error string or
-                                `'request_delete_confirmation_for_item'` if the user has to confirm the deletion
-                                after the user wiped the item id string or
-                                `'request_delete_confirmation_for_node'` if the user has to confirm the
-                                removal of the sub-node.
+        :param old_idx:             index in the current node of the edited item or -1 if a new item got edited.
+        :param new_id:              new/edited id string.
+        :param want_node:           True if the new/edited item will have a sub-node, False if not.
+        :param toggle_sel:          True if the selection state of the item has to be toggled.
+        :param toggle_unselected:   True will only toggle the unselected sub-item leafs, False only the selected ones.
+                                    This arg will only have an effect on toggling of a node item at the sub-leaf
+                                    selection states.
+        :return:                    empty string on successful validation, else error string or
+                                    `'request_delete_confirmation_for_item'` if the user has to confirm the deletion
+                                    after the user wiped the item id string or
+                                    `'request_delete_confirmation_for_node'` if the user has to confirm the
+                                    removal of the sub-node.
         """
         add_item = old_idx == -1
         if new_id is None:
@@ -376,7 +381,7 @@ class LiszDataMixin(ABC):
                     nid.pop('node')         # remove empty node
 
         if toggle_sel:
-            self.toggle_item_sel(new_idx)
+            self.toggle_item_sel(new_idx, toggle_unselected)
 
         self.play_sound('added' if add_item else 'edited')
 
@@ -761,13 +766,21 @@ class LiszDataMixin(ABC):
 
         return sub_item_ids
 
-    def toggle_item_sel(self, node_idx: int):
+    def toggle_item_sel(self, node_idx: int, toggle_unselected: bool = False):
         """ update the item selection data of the item identified by the list index in the current node.
 
-        :param node_idx:        list index of the item in the current node to change the selection for.
+        .. note::
+            Added `_ = toggle_unselected` to prevent pylint/PyCharm warnings, because this implementation does not use
+            the :paramref:`~toggle_item_sel.toggle_unselected` argument. Only some implementations (e.g.
+            <https://gitlab.com/ae-group/kivy_lisz>`_) allow to de-/select the sub-item leafs of a node
+            using this argument.
+
+        :param node_idx:            list index of the item in the current node to change the selection for.
+        :param toggle_unselected:   True will only toggle the unselected sub-item leafs, False only the selected ones.
         """
-        new_sel = not self.current_node_items[node_idx].get('sel', False)
-        if new_sel:
-            self.current_node_items[node_idx]['sel'] = 1
-        else:
+        _ = toggle_unselected
+        selected = self.current_node_items[node_idx].get('sel', False)
+        if selected:
             self.current_node_items[node_idx].pop('sel')
+        else:
+            self.current_node_items[node_idx]['sel'] = 1
